#include "TArtCalibPID.h" 
#include "TArtPPAC.h"
#include "TArtIC.h"
#include "TArtPlastic.h"
#include "TArtBigRIPSParameters.h"
#include "TArtRawEventObject.h"
#include "TArtCore.h" 
#include "TArtMapper.h" 

#include <TROOT.h>

#include "segidlist.h"

//__________________________________________________________
TArtCalibPID::TArtCalibPID()
  :fReconstructed(false)
{
  TArtCore::Info(__FILE__,"Creating the PID detector objects...");
  setup = (TArtBigRIPSParameters*)gROOT->FindObject("BigRIPSParameters");
  Initialize();
}

//__________________________________________________________
TArtCalibPID::TArtCalibPID(TArtBigRIPSParameters * s)
  :fReconstructed(false), setup(s)
{
  TArtCore::Info(__FILE__,"Creating the PID detector objects...");
  Initialize();
}

//__________________________________________________________
TArtCalibPID::~TArtCalibPID()  {
}

//__________________________________________________________
void TArtCalibPID::Initialize()  {

  mapper = TArtMapper::Instance();

  fPPAC = new TArtPPACArray(setup);
  fPlastic = new TArtPlasticArray(setup);
  fIC   = new TArtICArray(setup);

  fPPAC->LoadRawDataMap(mapper);
  fPlastic->LoadRawDataMap(mapper);
  fIC->LoadRawDataMap(mapper);

}

//
// use this function only when you analyse TArtRawEventObject tree.
//__________________________________________________________
void TArtCalibPID::LoadRawData(TArtRawEventObject *fEvent)   {

  ClearData();
  unsigned int * pdata;
  for(int i=0;i<fEvent->GetNumSeg();i++){
    TArtRawSegmentObject *seg = fEvent->GetSegment(i);
    int dev      = seg->GetDevice();
    int fpl      = seg->GetFP();
    int detector = seg->GetDetector();
    for(int j=0;j<seg->GetNumData();j++){
      TArtRawDataObject *d = seg->GetData(j);
      int geo = d->GetGeo(); 
      int ch = d->GetCh(); 
      unsigned int val = d->GetVal();
      //dev is not used since fpl is enough to identify
      TArtRIDFMap mm(fpl,detector,geo,ch);
      pdata = mapper->FindRecoMap(&mm);
      if(pdata != NULL){ *pdata = val; }
    }
  }

  return;

}

//__________________________________________________________
void TArtCalibPID::ClearData()   {

  fPPAC   ->ClearData();
  fPlastic->ClearData();
  fIC     ->ClearData();
  fReconstructed = false;

  return;

}

void TArtCalibPID::ReconstructData(TArtRawEventObject *fEvent)   {
  LoadRawData(fEvent);
  ReconstructData();
  return;
}

//__________________________________________________________
void TArtCalibPID::ReconstructData()   { // call after the raw data are loaded

  fPPAC   ->ReconstructData();
  fIC     ->ReconstructData();
  fPlastic->ReconstructData();              
  fReconstructed = true;

  return;

}

//__________________________________________________________
TArtPPAC * TArtCalibPID::GetPPAC(int i) {
  return (TArtPPAC *)fPPAC->At(i);
}
//__________________________________________________________
TArtPlastic * TArtCalibPID::GetPlastic(int i) {
  return (TArtPlastic *)fPlastic->At(i);
}
//__________________________________________________________
TArtIC * TArtCalibPID::GetIC(int i) {
  return (TArtIC *)fIC->At(i);
}
//__________________________________________________________
Int_t TArtCalibPID::GetNumPPAC() {
  return fPPAC->GetEntries();
}
//__________________________________________________________
Int_t TArtCalibPID::GetNumPlastic() {
  return fPlastic->GetEntries();
}
//__________________________________________________________
Int_t TArtCalibPID::GetNumIC() {
  return fIC->GetEntries();
}
