#include "TArtCore.h"
#include "TArtMap.h"
#include "TArtDALIParameters.h"
#include "TArtDALIPara.h"

#include <TROOT.h>
#include <TDOMParser.h>
#include <TXMLNode.h>

#include <stdlib.h>
#include <iostream>
#include <fstream>

//__________________________________________________________
TArtDALIParameters::TArtDALIParameters() : TNamed("DALIParameters","DALIParameters")
{
  TArtCore::Info(__FILE__,"Creating eurica setup...");
  gROOT->GetList()->Add(this);
}

//__________________________________________________________
TArtDALIParameters::~TArtDALIParameters() 
{
}

//__________________________________________________________
Bool_t TArtDALIParameters::LoadParameter(char *xmlfile)
{
  TArtCore::Info(__FILE__,"Load parameter from %s", xmlfile);
  TDOMParser *domParser = new TDOMParser();
  domParser->SetValidate(false);
  Int_t parsecode = domParser->ParseFile(xmlfile);
  if (parsecode < 0) {
    cerr << domParser->GetParseCodeMessage(parsecode) << endl;
    return false;
  }
  TXMLNode * node = domParser->GetXMLDocument()->GetRootNode();
  ParseParaList(node->GetChildren());
  itrEnd = pmap.end();
  return true;
}

//__________________________________________________________
void TArtDALIParameters::ParseParaList(TXMLNode *node) {
  for (; node; node = node->GetNextNode()) {
    if (node->GetNodeType() == TXMLNode::kXMLElementNode) { // Element Node
      if (strcmp(node->GetNodeName(), "DALI") == 0){
	TArtDALIPara * para = ParseDALIPara(node->GetChildren());
	pmap.insert(std::pair<TArtRIDFMap, TArtDALIPara *>(*((TArtRIDFMap *)para->GetADCMap()), para));
	pmap.insert(std::pair<TArtRIDFMap, TArtDALIPara *>(*((TArtRIDFMap *)para->GetTDCMap()), para));
      }
    }
  }
  return;
}

//__________________________________________________________
TArtDALIPara *TArtDALIParameters::ParseDALIPara(TXMLNode *node) {

  Int_t     id = -1;
  TString name;
  Int_t     fpl = -1;
  Int_t     layer = -1;
  Double_t  tcal = 0;
  Double_t  toff = 0;
  Double_t  qcal = 0;
  Double_t  qped = 0;
  Double_t  theta = 0;
  Int_t tdc_geo, tdc_ch, adc_geo, adc_ch;

  for ( ; node; node = node->GetNextNode()) {
    if (node->GetNodeType() == TXMLNode::kXMLElementNode) { // Element Node
      if (strcmp(node->GetNodeName(), "Id") == 0) 
	id = atoi(node->GetText());
      if (strcmp(node->GetNodeName(), "NAME") == 0) 
	name = node->GetText();
      if (strcmp(node->GetNodeName(), "FPL") == 0) 
	fpl = atoi(node->GetText());
      if (strcmp(node->GetNodeName(), "layer") == 0) 
	layer = atoi(node->GetText());
      if (strcmp(node->GetNodeName(), "tcal") == 0)
	tcal = (Double_t)atof(node->GetText());
      if (strcmp(node->GetNodeName(), "toff") == 0)
	toff = (Double_t)atof(node->GetText());
      if (strcmp(node->GetNodeName(), "qcal") == 0)
	qcal = (Double_t)atof(node->GetText());
      if (strcmp(node->GetNodeName(), "qped") == 0)
	qped = (Double_t)atof(node->GetText());
      if (strcmp(node->GetNodeName(), "theta") == 0)
	theta = (Double_t)atof(node->GetText());

      if (strcmp(node->GetNodeName(), "tdc_geo") == 0) 
	tdc_geo = atoi(node->GetText());
      if (strcmp(node->GetNodeName(), "tdc_ch") == 0) 
	tdc_ch = atoi(node->GetText());
      if (strcmp(node->GetNodeName(), "adc_geo") == 0) 
	adc_geo = atoi(node->GetText());
      if (strcmp(node->GetNodeName(), "adc_ch") == 0) 
	adc_ch = atoi(node->GetText());
    }
  }
  
  TArtCore::Info(__FILE__,"Reading database for %s DALI",name.Data());
  TArtDALIPara * para = new TArtDALIPara(id, name, fpl, layer, tcal, toff, qcal, qped, theta);
  //  para->SetName((name+"Para").Data());
  para->SetMap(tdc_geo, tdc_ch, adc_geo, adc_ch);

  return para;

}

TArtDALIPara * TArtDALIParameters::GetDALIPara(TArtRIDFMap *rmap){

  itr = pmap.find(*rmap);
  if(itr != itrEnd){
    return (TArtDALIPara*)itr->second;
  }
  return NULL;

}
