#ifndef _TARTNEBULA_H_
#define _TARTNEBULA_H_

#include <TClonesArray.h>
#include "TArtCalibNEBULA.h"

class TArtNEBULAParameters;
class TArtNEBULAPara;
class TArtTOF;

class TArtNEBULAArray : public TClonesArray {

 public:
  TArtNEBULAArray();
  virtual ~TArtNEBULAArray(){}
  virtual TArtNEBULA * FindPla(Int_t id);
  virtual void ReconstructData();
  virtual void DopplerCorrect(TArtTOF *tof);

  ClassDef(TArtNEBULAArray,1);
};

class TArtNEBULA: public TNamed {

 public:
  TArtNEBULA(TArtNEBULAPara *p);
  virtual ~TArtNEBULA();

  void   ReconstructData();
  Bool_t IsReconstructed(){ return fReconstructed; }

  void   DopplerCorrect(TArtTOF *tof);

  // calibration parameter
  Int_t  GetID();
  Int_t  GetFpl();
  const TString& GetDetectorName();

  // function to set raw data
  void  SetChannel(int val){channel = val;}
  void  SetRawADC(int val){fADC = val;}
  void  SetRawTDC(int val){fTDC = val;}

  // function to get raw data
  int  GetChannel(){return channel;}
  int  GetRawADC(){return fADC;}
  int  GetRawTDC(){return fTDC;}

  // function to set reco data
  void  SetEnergy(int val){fEnergy = val;}
  void  SetTime(int val){fTime = val;}

  // function to get reco data
  Double_t GetEnergy(){return fEnergy;}
  Double_t GetDoppCorEnergy(){return fDoppCorEnergy;}
  Double_t GetTime(){return fTime;}

  const TArtNEBULAPara* GetPara(){return (const TArtNEBULAPara*)para;}

 private:
  int fADC;  
  int fTDC;  

  int channel;  
  Double_t fEnergy;  
  Double_t fDoppCorEnergy;  
  Double_t fTime;  

  bool fReconstructed;
  TArtNEBULAPara *para;

  ClassDef(TArtNEBULA,1);

};
#endif

