#include "TArtNEBULA.h" 
#include "TArtNEBULAPara.h" 
#include "TArtCore.h" 
#include "TArtNEBULAParameters.h"
#include "TArtTOF.h"

#include <TRandom.h>
#include <TMath.h>

//__________________________________________________________
TArtNEBULAArray::TArtNEBULAArray() :
  TClonesArray("TArtNEBULA",100)
{
}

//__________________________________________________________
TArtNEBULA * TArtNEBULAArray::FindPla(Int_t id) 
{
  for(int i=0;i<GetEntries();i++)
    if(  id == ((TArtNEBULA*)At(i))->GetID() )
      return (TArtNEBULA*)At(i);

  return NULL;
}

//__________________________________________________________
void TArtNEBULAArray::ReconstructData() 
{
  for(int i=0;i<GetEntries();i++)
    ((TArtNEBULA*)At(i))->ReconstructData();
}

//__________________________________________________________
void TArtNEBULAArray::DopplerCorrect(TArtTOF *tof){
  for(int i=0;i<GetEntries();i++)
    ((TArtNEBULA*)At(i))->DopplerCorrect((TArtTOF*)tof);
}


//__________________________________________________________
TArtNEBULA::TArtNEBULA(TArtNEBULAPara *p)
  :fReconstructed(false), para(p), fADC(-1000), fTDC(-1000),
   channel(-1000), fEnergy(-1000), fTime(-1000)
{
}

//__________________________________________________________
TArtNEBULA::~TArtNEBULA()  {
}

//__________________________________________________________
void TArtNEBULA::ReconstructData()  {

  static TRandom *r = new TRandom();
  if(fTDC>0 && fADC>0 && fTDC<100000 && fADC<100000){
  }
  else{ return; }

  float random = r->Rndm();
  fTime = (fTDC + random) * para->GetTCal();
  random = r->Rndm();
  fEnergy = (fADC + random - para->GetQPed()) * para->GetQCal();
  
  fReconstructed = true;

}

//__________________________________________________________
void TArtNEBULA::DopplerCorrect(TArtTOF *tof){

  if(!fReconstructed){
    TArtCore::Info(__FILE__,"Data is not reconstructed.");
    return;
  }

  // reconstructed position and angle based on PPAC information is too fine and not used since the most of the resolution is determined by DALI-NaI angle resolution.

  Double_t fBeta = tof->GetBeta();
  fDoppCorEnergy = fEnergy;
  //  fDoppCorEnergy = fEnergy * (1-fBeta*TMath::Cos(para->GetNaITheta()))/TMath::Sqrt((1.0-fBeta*fBeta));

}

//__________________________________________________________
Int_t TArtNEBULA::GetID() {
  return para->GetID();
}
//__________________________________________________________
const TString& TArtNEBULA::GetDetectorName() {
  return para->GetDetectorName();
}
//__________________________________________________________
Int_t TArtNEBULA::GetFpl() {
  return para->GetFpl();
}

